.. _authors:

Authors
-------

.. image:: https://img.shields.io/github/contributors/pyvista/pyvista.svg?logo=github&logoColor=white
   :target: https://github.com/pyvista/pyvista/graphs/contributors/


The following is a list of authors who have made substantial contributions to
the conception or design of this software; or the creation of new code used in
this software; or have drafted the work or substantively revised it and are
considered "The PyVista Developers":

- Alex Kaszynski, (`@akaszynski <https://github.com/akaszynski/>`_)
- Bane Sullivan, (`@banesullivan <https://github.com/banesullivan/>`_)
- Henrik Åhl, (`@supersubscript <https://github.com/supersubscript/>`_)
- Guillaume Favelier, (`@GuillaumeFavelier <https://github.com/GuillaumeFavelier/>`_)
- Jevin Jones, (`@JevinJ <https://github.com/JevinJ/>`_)
- András Deák, (`@adeak <https://github.com/adeak>`_)
- Tetsuo Koyama, (`@tkoyama010 <https://github.com/tkoyama010>`_)
- Rodrigo Mologni, (`@rodrigomologni <https://github.com/rodrigomologni>`_)
- Phil Chiu, (`@whophil <https://github.com/whophil>`_)
- Thomas G., (`@thomgrand <https://github.com/thomgrand>`_)
- Eric Larson, (`@larsoner <https://github.com/larsoner>`_)
- Matthew Flamm, (`@MatthewFlamm <https://github.com/MatthewFlamm>`_)
- Darik Gamble, (`@darikg <https://github.com/darikg>`_)
- Bram De Cooman, (`@dcbr <https://github.com/dcbr>`_)
- `@user27182 <https://github.com/user27182>`_


.. |contrib.rocks| image:: https://contrib.rocks/image?repo=pyvista/pyvista
   :target: https://github.com/pyvista/pyvista/graphs/contributors
   :alt: contrib.rocks

Please take a look at the `contributors page`_ and the active `list of authors`_
to learn more about the developers of PyVista.

|contrib.rocks|

Made with `contrib rocks`_.

.. _contributors page: https://github.com/pyvista/pyvista/graphs/contributors/
.. _list of authors: https://docs.pyvista.org/getting-started/authors.html#authors
.. _contrib rocks: https://contrib.rocks
